==> haskell-byte-order-0.1.3.1-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byte-order.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 byte-order
version:              0.1.3.1
visibility:           public
id:                   byte-order-0.1.3.1-9sC6qj79kKIBBMdwOGhRoD
key:                  byte-order-0.1.3.1-9sC6qj79kKIBBMdwOGhRoD
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           amartin@layer3com.com
author:               Andrew Martin
homepage:             https://github.com/byteverse/byte-order
synopsis:             Portable big-endian and little-endian conversions
description:
    This library provides an interface to portably work with byte
    arrays whose contents are known to be of a fixed endianness.
    There are two ways to use this module. See the `System.ByteOrder`
    module for more documentation.

category:             Data
abi:                  f5d62207a231d9ac2d1a372e8c7f13e0
exposed:              True
exposed-modules:
    Data.Primitive.ByteArray.BigEndian
    Data.Primitive.ByteArray.LittleEndian Data.Primitive.Ptr.BigEndian
    System.ByteOrder System.ByteOrder.Class

import-dirs:          /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byte-order
hs-libraries:         HSbyte-order-0.1.3.1-9sC6qj79kKIBBMdwOGhRoD
depends:
    base-4.17.2.1 primitive-0.9.0.0-BwFGxoQzg5B2yfW1w0zNtL
    primitive-unaligned-0.1.1.2-1MPpfTdkrVO7Nsei8aWdNp
    wide-word-0.1.7.1-51YcrrsUbe0KfZqDHc99ox

haddock-interfaces:   /usr/share/doc/haskell-byte-order/html/byte-order.haddock
haddock-html:         /usr/share/doc/haskell-byte-order/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byte-order-0.1.3.1-83-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byte-order.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 byte-order
version:              0.1.3.1
visibility:           public
id:                   byte-order-0.1.3.1-9TPyFwq8buj25kTNq9nD30
key:                  byte-order-0.1.3.1-9TPyFwq8buj25kTNq9nD30
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           amartin@layer3com.com
author:               Andrew Martin
homepage:             https://github.com/byteverse/byte-order
synopsis:             Portable big-endian and little-endian conversions
description:
    This library provides an interface to portably work with byte
    arrays whose contents are known to be of a fixed endianness.
    There are two ways to use this module. See the `System.ByteOrder`
    module for more documentation.

category:             Data
abi:                  29c0fef2acc179d84738a342c05e1528
exposed:              True
exposed-modules:
    Data.Primitive.ByteArray.BigEndian
    Data.Primitive.ByteArray.LittleEndian Data.Primitive.Ptr.BigEndian
    System.ByteOrder System.ByteOrder.Class

import-dirs:          /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byte-order
hs-libraries:         HSbyte-order-0.1.3.1-9TPyFwq8buj25kTNq9nD30
depends:
    base-4.17.2.1 primitive-0.9.0.0-1uQl5SMm5FQ52SaicTkt1Y
    primitive-unaligned-0.1.1.2-3Fgue0r2QNM8xV7AoFiq9F
    wide-word-0.1.7.1-24kWbSjI9KdLSyF3YrL60w

haddock-interfaces:   /usr/share/doc/haskell-byte-order/html/byte-order.haddock
haddock-html:         /usr/share/doc/haskell-byte-order/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
